@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #ifndef GLOM_DB_UTILS_H
@@ -32,7 +32,7 @@ namespace DbUtils
 
 bool create_database(Document* document, const Glib::ustring& database_name, const Glib::ustring& title, const sigc::slot<void>& progress);
 
-//TODO: Use this in Glom::Application?
+//TODO: Use this in Glom::AppWindow?
 /** Create the database on an already-connected server.
  */
 bool recreate_database_from_document(Document* document, const sigc::slot<void>& progress);
@@ -70,8 +70,11 @@ type_vec_fields get_fields_for_table(const Document* document, const Glib::ustri
  */
 sharedptr<Field> get_fields_for_table_one_field(const Document* document, const Glib::ustring& table_name, const Glib::ustring& field_name);
 
-//TODO: Is this used directly?
 typedef std::vector<Glib::ustring> type_vec_strings;
+
+/** Get the table names from the database server.
+ * This could theoretically be different than the ones listed in the document.
+ */
 type_vec_strings get_table_names_from_database(bool ignore_system_tables = false);
 
 bool get_table_exists_in_database(const Glib::ustring& table_name);
@@ -90,7 +93,8 @@ bool add_column(const Glib::ustring& table_name, const sharedptr<const Field>& f
 bool drop_column(const Glib::ustring& table_name, const Glib::ustring& field_name);
 
 
-//TODO: Is this used directly?
+/** Insert example data, from the document, into the table on the database server.
+ */
 bool insert_example_data(Document* document, const Glib::ustring& table_name);
 
 /** Execute a SQL Select command, returning the result.
@@ -114,11 +118,14 @@ bool query_execute_string(const Glib::ustring& strQuery,
   */
 bool query_execute(const Glib::RefPtr<const Gnome::Gda::SqlBuilder>& builder);
 
-//TODO: Is this used directly?
+/** Insert the auto-increment row in the database preferences table, if necessary,
+ * returning the next value.
+ */
 Gnome::Gda::Value auto_increment_insert_first_if_necessary(const Glib::ustring& table_name, const Glib::ustring& field_name);
 
 /** Get the next auto-increment value for this primary key, from the glom system table.
   * Add a row for this field in the system table if it does not exist already.
+  * This increments the next value after obtaining the current next value.
   */
 Gnome::Gda::Value get_next_auto_increment_value(const Glib::ustring& table_name, const Glib::ustring& field_name);
 
@@ -179,6 +186,23 @@ Glib::ustring build_query_create_group(const Glib::ustring& group, bool superuse
 
 Glib::ustring build_query_add_user_to_group(const Glib::ustring& group, const Glib::ustring& user);
 
+/** Add a @a user to the database, with the specified @a password, in the specified @a group.
+ * @result true if the addition succeeded.
+ */
+bool add_user(const Document* document, const Glib::ustring& user, const Glib::ustring& password, const Glib::ustring& group);
+
+/** Remove the @a user from the database.
+ * @result true if the removal succeeded.
+ */
+bool remove_user(const Glib::ustring& user);
+
+/** Add a @a group to the database.
+ * @result true if the addition succeeded.
+ */
+bool add_group(const Document* document, const Glib::ustring& group, bool superuser = false);
+
+bool remove_user_from_group(const Glib::ustring& user, const Glib::ustring& group);
+
 /** Get the value of the @a source_field from the @a relationship, using the @a key_value.
  */
 Gnome::Gda::Value get_lookup_value(Document* document, const Glib::ustring& table_name, const sharedptr<const Relationship>& relationship, const sharedptr<const Field>& source_field, const Gnome::Gda::Value & key_value);
