@@ -14,12 +14,14 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
 
+#include <iostream>
+
 //We use Python for calculated fields.
 //#include <Python.h> //Include it before anything else to avoid "_POSIX_C_SOURCE redefined".
 #include <boost/python.hpp>
